@@ -47,7 +47,7 @@ extern std::queue<XCVR_STATE> queB;
 
 void read_KX3_vfo()
 {
-	unsigned long int freq;
+	unsigned long long freq;
 	freq = selrig->get_vfoA();
 	if (freq != vfoA.freq) {
 		vfoA.freq = freq;
@@ -106,7 +106,6 @@ void cb_KX3_A2B()
 	selrig->set_bwB(vfoB.iBW);
 	selrig->set_modeB(vfoB.imode);
 	FreqDispB->value(vfoB.freq);
-	Fl::focus(FreqDispA);
 }
 
 void cb_KX3_swapAB()
@@ -133,7 +132,6 @@ void cb_KX3_swapAB()
 
 	FreqDispB->value(vfoB.freq);
 
-	Fl::focus(FreqDispA);
 }
 
 void cb_KX3_IFsh()
