@@ -43,6 +43,7 @@ Fl_Menu_Item touch_menu[] = {
  {_("Other"), 0, (Fl_Callback*)cb_mnuOTHER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("TMATE-2"), 0, (Fl_Callback*)cb_mnuTMATE2, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Server"), 0, (Fl_Callback*)cb_mnuSERVER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Client"), 0, (Fl_Callback*)cb_mnuCLIENT, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Polling"), 0, (Fl_Callback*)cb_Polling, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Commands"), 0, (Fl_Callback*)cb_mnuCommands, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Send command"), 0, (Fl_Callback*)cb_Send, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
@@ -423,22 +424,16 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 		opFilterOuter->tooltip("Outer cutoff");
 		opFilterOuter->hide();
 
-		opBW_A = new Fl_Counter(xpos+30, ypos, opBW->w() - 30, 35, _("BW vfoA"));
-		opBW_A->minimum(50);
-		opBW_A->maximum(4000);
-		opBW_A->step(10);
-		opBW_A->lstep(100);
-		opBW_A->align(Fl_Align(FL_ALIGN_LEFT));
+		opBW_A = new Fl_ComboBox(xpos+30, ypos, opBW->w() - 30, 35, _("BW vfoA"));
 		opBW_A->tooltip("BW vfoA");
+		opBW_A->align(Fl_Align(FL_ALIGN_LEFT));
+		opBW_A->end();
 		opBW_A->hide();
 
-		opBW_B = new Fl_Counter(xpos+30, ypos, opBW->w() - 30, 35, _("BW vfoB"));
-		opBW_B->minimum(50);
-		opBW_B->maximum(4000);
-		opBW_B->step(10);
-		opBW_B->lstep(100);
+		opBW_B = new Fl_ComboBox(xpos+30, ypos, opBW->w() - 30, 35, _("BW vfoB"));
 		opBW_B->align(Fl_Align(FL_ALIGN_LEFT));
 		opBW_B->tooltip("Bw vfoB");
+		opBW_B->end();
 		opBW_B->hide();
 
 		grpcombos->end();
