@@ -53,6 +53,7 @@
 #include "threads.h"
 #include "debug.h"
 #include "util.h"
+#include "support.h"
 #include "status.h"
 
 #include "hidapi.h"
@@ -64,7 +65,7 @@
 
 int ChangeSpeedEvalTime_ms = 500;
 
-static map<std::string, std::string> paths;
+static std::map<std::string, std::string> paths;
 static hid_device *tm2_dev = (hid_device *)0;
 
 //this is used for writing to USB it contains settings, LED and LCD symbols
