@@ -20,7 +20,7 @@
 // along with fldigi.  If not, see <http://www.gnu.org/licenses/>.
 // ---------------------------------------------------------------------
 
-#include <config.h>
+#include "config.h"
 #include <cstring>
 #include <iostream>
 
@@ -120,7 +120,7 @@ CWstruct Cmorse::cw_table[] = {
 	{ "9", "----." },
 
 // punctuation
-	{ "\\", ".-..-." },
+	{ "\"", ".-..-." },
 	{ "\'", ".----." },
 	{ "$", "...-..-" },
 	{ "(", "-.--."	 },
