@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _IC703_H
@@ -32,8 +32,8 @@ public:
 
 	bool check();
 
-	unsigned long int get_vfoA(void);
-	void set_vfoA(unsigned long int);
+	unsigned long long get_vfoA(void);
+	void set_vfoA(unsigned long long);
 
 	void set_modeA(int val);
 	int  get_modeA();
@@ -48,9 +48,14 @@ public:
 
 	void set_attenuator(int val);
 	int  get_attenuator();
+
 	int  next_preamp();
 	void set_preamp(int val);
 	int  get_preamp();
+
+	const char * PRE_label();
+	const char * ATT_label();
+
 	void set_compression(int, int);
 	void get_comp_min_max_step(int &min, int &max, int &step) {
 		min = 0; max = 10; step = 1; }
@@ -89,10 +94,6 @@ public:
 	void set_mic_gain(int val);
 	void get_mic_gain_min_max_step(int &min, int &max, int &step);
 
-	void set_if_shift(int val);
-	bool get_if_shift(int &val);
-	void get_if_min_max_step(int &min, int &max, int &step);
-
 	void set_pbt_inner(int val);
 	void set_pbt_outer(int val);
 
