@@ -253,7 +253,6 @@ public:
 	bool has_volume_control;
 	bool has_mode_control;
 	bool has_bandwidth_control;
-	bool has_int_bandwidth_control;
 	bool has_dsp_controls;
 	bool has_FILTER;
 	bool has_micgain_control;
@@ -361,7 +360,7 @@ public:
 	rigbase();
 	virtual ~rigbase(){}
 
-	virtual void initialize() {}
+	virtual void initialize();
 	virtual void post_initialize() {}
 	virtual void shutdown() {}
 
@@ -664,6 +663,8 @@ double vfo_;
 	int waitN(int n, int timeout, const char *, int pr = HEX);
 	int wait_char(int ch, int n, int timeout, const char *, int pr = HEX);
 	int wait_crlf(std::string, std::string, int nr = 20, int timeout = 100, int pr = ASC);
+	int wait_string(std::string sz, int nr, int timeout = 100, int pr = ASC);
+	int waitfor(int nr, int timeout = 100, int pr = ASC);
 
 // IC-7610
 	virtual void set_digi_sel(bool) {}
