@@ -21,24 +21,24 @@
 #ifndef WRAP_H
 #define WRAP_H
 
+#ifdef WIN32
+#  include "compat.h"
+#else
+#  include <arpa/inet.h>
+#endif
+
 #include <string.h>
 #include <string>
 
 #include "threads.h"
 #include "socket.h"
 
-#ifdef WIN32
-#  include <winsock2.h>
-#else
-#  include <arpa/inet.h>
-#endif
-
 extern Socket *tcpip;
 extern Address *remote_addr;
 
 void connect_to_remote();
 void disconnect_from_remote();
-void send_to_remote(std::string cmd_string, int pace = 0);
+void send_to_remote(std::string cmd_string);
 int  read_from_remote(std::string &str);
 
 #endif
