@@ -153,6 +153,8 @@ extern void setDSP();
 extern void selectDSP();
 extern void selectFILT();
 extern void selectCENTER();
+extern void setFilterInner();
+extern void setFilterOuter();
 
 extern void addFreq();
 extern void delFreq();
@@ -294,6 +296,7 @@ extern void open_ptt_tab();
 extern void open_gpio_tab();
 extern void open_other_tab();
 extern void open_server_tab();
+extern void open_client_tab();
 extern void open_tmate2_tab();
 
 extern void cb_close_TT550_setup();
