@@ -87,7 +87,7 @@ public:
 	void checkresponse();
 	int  adjust_bandwidth(int);
 	int  def_bandwidth(int);
-	const char **bwtable(int);
+	std::vector<std::string>& bwtable(int);
 };
 
 
