@@ -77,6 +77,9 @@ public:
 	virtual int  get_swr();
 	virtual int  get_alc();
 	virtual int  get_power_out();
+	virtual double  get_voltmeter();
+	virtual double  get_idd();
+
 	virtual double get_power_control();
 	virtual void set_power_control(double val);
 	virtual void get_pc_min_max_step(double &min, double &max, double &step) {
