@@ -32,9 +32,11 @@ bool IC7410_DEBUG = true;
 
 const char IC7410name_[] = "IC-7410";
 
-const char *IC7410modes_[] = {
+static std::vector<std::string>IC7410modes_;
+static const char *vIC7410modes_[] =
+{
 	"LSB", "USB", "AM", "CW", "RTTY", "FM",  "CW-R", "RTTY-R", 
-	"LSB-D", "USB-D", "FM-D", NULL};
+	"LSB-D", "USB-D", "FM-D"};
 
 enum {
 	LSB7410, USB7410, AM7410, CW7410, RTTY7410, FM7410,  CWR7410, RTTYR7410,
@@ -57,31 +59,36 @@ const char IC7410_mode_nbr[] = {
 	0x05, // select fm-data mode
 };
 
-const char *IC7410_ssb_bws[] = {
+static std::vector<std::string>IC7410_ssb_bws;
+static const char *vIC7410_ssb_bws[] =
+{
 "50",    "100",  "150",  "200",  "250",  "300",  "350",  "400",  "450",  "500",
 "600",   "700",  "800",  "900", "1000", "1100", "1200", "1300", "1400", "1500",
 "1600", "1700", "1800", "1900", "2000", "2100", "2200", "2300", "2400", "2500",
 "2600", "2700", "2800", "2900", "3000", "3100", "3200", "3300", "3400", "3500",
-"3600",
-NULL };
+"3600"};
 
-const char *IC7410_rtty_bws[] = {
+static std::vector<std::string>IC7410_rtty_bws;
+static const char *vIC7410_rtty_bws[] =
+{
 "50",    "100",  "150",  "200",  "250",  "300",  "350",  "400",  "450",  "500",
 "600",   "700",  "800",  "900", "1000", "1100", "1200", "1300", "1400", "1500",
 "1600", "1700", "1800", "1900", "2000", "2100", "2200", "2300", "2400", "2500",
-"2600", "2700",
-NULL };
+"2600", "2700"};
 
-const char *IC7410_am_bws[] = {
+static std::vector<std::string>IC7410_am_bws;
+static const char *vIC7410_am_bws[] =
+{
 "200",   "400",  "600",  "800", "1000", "1200", "1400", "1600", "1800", "2000",
 "2200", "2400", "2600", "2800", "3000", "3200", "3400", "3600", "3800", "4000",
 "4200", "4400", "4600", "4800", "5000", "5200", "5400", "5600", "5800", "6000",
 "6200", "6400", "6600", "6800", "7000", "7200", "7400", "7410", "7800", "8000",
-"8200", "8400", "8600", "8800", "9000", "9200", "9400", "9600", "9800", "10000", 
-NULL };
+"8200", "8400", "8600", "8800", "9000", "9200", "9400", "9600", "9800", "10000"};
 
-const char *IC7410_fm_bws[] = {
-"FIXED", NULL };
+static std::vector<std::string>IC7410_fm_bws;
+static const char *vIC7410_fm_bws[] =
+{
+"FIXED" };
 
 static GUI IC7410_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 },	//0
@@ -104,6 +111,16 @@ static GUI IC7410_widgets[]= {
 
 void RIG_IC7410::initialize()
 {
+	VECTOR (IC7410modes_, vIC7410modes_);
+	VECTOR (IC7410_ssb_bws, vIC7410_ssb_bws);
+	VECTOR (IC7410_rtty_bws, vIC7410_rtty_bws);
+	VECTOR (IC7410_am_bws, vIC7410_am_bws);
+	VECTOR (IC7410_fm_bws, vIC7410_fm_bws);
+
+	modes_ = IC7410modes_;
+	bandwidths_ = IC7410_ssb_bws;
+	_mode_type = IC7410_mode_type;
+
 	IC7410_widgets[0].W = btnVol;
 	IC7410_widgets[1].W = sldrVOLUME;
 	IC7410_widgets[2].W = btnAGC;
@@ -409,25 +426,24 @@ int RIG_IC7410::adjust_bandwidth(int m)
 	return 0;
 }
 
-const char ** RIG_IC7410::bwtable(int m)
+std::vector<std::string>& RIG_IC7410::bwtable(int m)
 {
-	const char **table;
 	switch (m) {
 		case AM7410:
-			table = IC7410_am_bws;
+			return IC7410_am_bws;
 			break;
 		case FM7410: case FMD7410:
-			table = IC7410_fm_bws;
+			return IC7410_fm_bws;
 			break;
 		case RTTY7410: case RTTYR7410:
-			table = IC7410_rtty_bws;
+			return IC7410_rtty_bws;
 			break;
 		case CW7410: case CWR7410:
 		case USB7410: case LSB7410: case LSBD7410 : case USBD7410:
 		default:
-			table = IC7410_ssb_bws;
+			return IC7410_ssb_bws;
 	}
-	return table;
+	return IC7410_ssb_bws;
 }
 
 int RIG_IC7410::def_bandwidth(int m)
