@@ -21,6 +21,7 @@
 
 #include "support.h"
 #include "ptt.h"
+#include "xmlrpc_rig.h"
 
 extern bool testmode;
 
@@ -147,14 +148,20 @@ void TRACED(adjust_small_ui)
 		if (selrig->has_pbt_controls) {
 			y += 20;
 			btnLOCK->position( 2, y);
-			btnLOCK->show();
+			if (selrig->name_ == rig_FLEX1500.name_)
+				btnLOCK->hide();
+			else
+				btnLOCK->show();
 			btnLOCK->redraw();
 			sldrINNER->resize( 54, y, 368, 18 );
 			sldrINNER->show();
 			sldrINNER->redraw();
 			y += 20;
 			btnCLRPBT->position( 2, y);
-			btnCLRPBT->show();
+			if (selrig->name_ == rig_FLEX1500.name_)
+				btnCLRPBT->hide();
+			else
+				btnCLRPBT->show();
 			btnCLRPBT->redraw();
 			sldrOUTER->resize( 54, y, 368, 18);
 			sldrOUTER->show();
@@ -450,15 +457,37 @@ void TRACED(adjust_wide_ui)
 		sldrIFSHIFT->show();
 	}
 	if (selrig->has_pbt_controls) {
-		btnLOCK->show();
-		btnLOCK->value(progStatus.pbt_lock);
-		btnCLRPBT->show();
-		sldrINNER->show();
-		sldrOUTER->show();
-		sldrINNER->value(progStatus.pbt_inner);
-		sldrINNER->redraw();
-		sldrOUTER->value(progStatus.pbt_outer);
-		sldrOUTER->redraw();
+		if (selrig->name_ == rig_FLEX1500.name_) {
+			sldrINNER->minimum(-4000);
+			sldrINNER->maximum(4000);
+			sldrINNER->step(50);
+			sldrINNER->tooltip(_("Lower PBT control"));
+			sldrINNER->label(_("Lower"));
+			sldrINNER->align(FL_ALIGN_LEFT);
+			sldrINNER->value(progStatus.pbt_inner);
+			sldrOUTER->minimum(-4000);
+			sldrOUTER->maximum(4000);
+			sldrOUTER->step(50);
+			sldrOUTER->tooltip(_("Upper PBT control"));
+			sldrOUTER->label(_("Upper"));
+			sldrOUTER->align(FL_ALIGN_LEFT);
+			sldrOUTER->value(progStatus.pbt_outer);
+			btnLOCK->hide();
+			btnIFsh->hide();
+			btnCLRPBT->hide();
+			sldrINNER->show();
+			sldrOUTER->show();
+		} else {
+			btnLOCK->show();
+			btnLOCK->value(progStatus.pbt_lock);
+			btnCLRPBT->show();
+			sldrINNER->show();
+			sldrOUTER->show();
+			sldrINNER->value(progStatus.pbt_inner);
+			sldrINNER->redraw();
+			sldrOUTER->value(progStatus.pbt_outer);
+			sldrOUTER->redraw();
+		}
 	}
 	btnNotch->show();
 	sldrNOTCH->show();
@@ -1294,17 +1323,6 @@ static void cb_pbt(Fl_Counter *, void *)
 
 void TRACED(init_dsp_controls)
 
-	if (selrig->has_int_bandwidth_control) {
-		opBW->hide();
-		opDSP_lo->hide();
-		opDSP_hi->hide();
-		btnDSP->hide();
-		btnFILT->hide();
-		opBW_A->show();
-		opBW_B->show();
-		return;
-	}
-
 	if (selrig->has_dsp_controls) {
 		opDSP_lo->clear();
 		opDSP_hi->clear();
@@ -1318,7 +1336,7 @@ void TRACED(init_dsp_controls)
 				opDSP_hi->add(selrig->dsp_SH.at(i).c_str());
 			opDSP_hi->tooltip(selrig->SH_tooltip);
 		} catch (const std::exception& e) {
-			std::cout << e.what() << '\n';
+			LOG_ERROR("%s", e.what());
 		}
 		if (vfo->iBW > 256) {
 			opDSP_lo->index(vfo->iBW & 0xFF);
@@ -1338,7 +1356,7 @@ void TRACED(init_dsp_controls)
 			btnFILT->hide();
 			opBW->show();
 		}
-	} else if (selrig->has_FILTER) { // && (xcvr_name != rig_KX3.name_) ) {
+	} else if (selrig->has_FILTER) {
 		btnDSP->hide();
 		opDSP_lo->hide();
 		opDSP_hi->hide();
@@ -1346,15 +1364,14 @@ void TRACED(init_dsp_controls)
 		opBW->resize(opDSP_lo->x(), opDSP_lo->y(), opDSP_lo->w(), opDSP_lo->h());
 		opBW->redraw();
 		opBW->show();
-	} else { //if ( (xcvr_name != rig_KX3.name_) ){
+	} else {
 		btnDSP->hide();
 		opDSP_lo->hide();
 		opDSP_hi->hide();
 		btnFILT->hide();
 		opBW->show();
 		if (selrig->name_ == rig_tci_sundx.name_ ||
-			selrig->name_ == rig_tci_sunpro.name_ ||
-			selrig->name_ == rig_FLEX1500.name_ ) {
+			selrig->name_ == rig_tci_sunpro.name_ ) {
 			opCENTER->clear();
 			for (int i = 0; i < tci_nbr_centers; i++)
 				opCENTER->add(TCI_centers[i].c_str());
@@ -1721,17 +1738,39 @@ void TRACED(init_if_shift_control)
 		}
 	}
 	if (selrig->has_pbt_controls) {
-		btnLOCK->show();
-		btnLOCK->value(progStatus.pbt_lock);
-		btnCLRPBT->show();
-		sldrINNER->show();
-		sldrOUTER->show();
-		sldrINNER->value(progStatus.pbt_inner);
-		sldrINNER->redraw();
-		sldrOUTER->value(progStatus.pbt_outer);
-		sldrOUTER->redraw();
-		selrig->set_pbt_outer(progStatus.pbt_outer);
-		selrig->set_pbt_inner(progStatus.pbt_inner);
+		if (selrig->name_ == rig_FLEX1500.name_) {
+			sldrINNER->minimum(-4000);
+			sldrINNER->maximum(4000);
+			sldrINNER->step(50);
+			sldrINNER->tooltip(_("Lower PBT control"));
+			sldrINNER->label(_("Lower"));
+			sldrINNER->align(FL_ALIGN_LEFT);
+			sldrINNER->redraw_label();
+			sldrOUTER->minimum(-4000);
+			sldrOUTER->maximum(4000);
+			sldrOUTER->step(50);
+			sldrOUTER->tooltip(_("Upper PBT control"));
+			sldrOUTER->label(_("Upperer"));
+			sldrOUTER->align(FL_ALIGN_LEFT);
+			sldrOUTER->redraw_label();
+			btnLOCK->hide();
+			btnIFsh->hide();
+			btnCLRPBT->hide();
+			sldrINNER->show();
+			sldrOUTER->show();
+		} else {
+			btnLOCK->show();
+			btnLOCK->value(progStatus.pbt_lock);
+			btnCLRPBT->show();
+			sldrINNER->show();
+			sldrOUTER->show();
+			sldrINNER->value(progStatus.pbt_inner);
+			sldrINNER->redraw();
+			sldrOUTER->value(progStatus.pbt_outer);
+			sldrOUTER->redraw();
+			selrig->set_pbt_outer(progStatus.pbt_outer);
+			selrig->set_pbt_inner(progStatus.pbt_inner);
+		}
 	}
 
 	if (xcvr_name == rig_TS870S.name_) {
@@ -2273,17 +2312,35 @@ Slider controls TX monitor level");
 	}
 }
 
-static void cb_bw_A(Fl_Counter *, void *)
+void cb_bw_A(Fl_ComboBox *, void *)
 {
-	selrig->set_bwA( opBW_A->value() );
+	int nubw = opBW_A->index();
+	guard_lock serial(&mutex_serial);
+	selrig->set_bwA( nubw );
+	vfoA.iBW = nubw;
+//	int timeout = 500; // msec
+//	while (timeout && (selrig->get_bwA() != nubw)) {
+//		MilliSleep(50);
+//		timeout -= 50;
+//		Fl::awake();
+//	}
 }
 
-static void cb_bw_B(Fl_Counter *, void *)
+void cb_bw_B(Fl_ComboBox *, void *)
 {
-	selrig->set_bwB( opBW_B->value() );
+	int nubw = opBW_B->index();
+	guard_lock serial(&mutex_serial);
+	selrig->set_bwB( nubw );
+	vfoB.iBW = nubw;
+//	int timeout = 500; // msec
+//	while (timeout && (selrig->get_bwB() != nubw)) {
+//		MilliSleep(50);
+//		timeout -= 50;
+//		Fl::awake();
+//	}
 }
 
-void TRACED(init_K3_KX3_special)
+void TRACED(init_elecraft_xcvrs)
 	if (!(xcvr_name == rig_K3.name_ || 
 		  xcvr_name == rig_KX3.name_ ||
 		  xcvr_name == rig_K4.name_ ) ) return;
@@ -2295,15 +2352,13 @@ void TRACED(init_K3_KX3_special)
 		btn_KX3_swapAB->hide();
 		btn_K3_swapAB->show();
 		btn_K3_A2B->show();
-	} else if (xcvr_name == rig_KX3.name_) {
-		btnB->hide();
-		btnA->hide();
-		btnAswapB->hide();
-		btn_K3_swapAB->hide();
-		btn_K3_A2B->hide();
-		btn_KX3_swapAB->show();
-		btn_KX3_A2B->show();
-	} else {
+		opBW_A->hide();
+		opBW_B->hide();
+		opBW->show();
+		return;
+	}
+
+	if (xcvr_name == rig_KX3.name_ || xcvr_name == rig_K4.name_) {
 		btn_K3_swapAB->hide();
 		btn_K3_A2B->hide();
 		btn_KX3_swapAB->hide();
@@ -2312,18 +2367,84 @@ void TRACED(init_K3_KX3_special)
 		btnB->show();
 		btnA->show();
 		btnAswapB->show();
-	}
+		opDSP_lo->hide();
+		opDSP_hi->hide();
+		btnDSP->hide();
+		btnFILT->hide();
+		opBW->hide();
 
-	if (progStatus.UIsize == small_ui) {
-		opBW_A->resize(212, 103, 104, 18);
-		opBW_A->redraw();
-		opBW_B->resize(318, 103, 104, 18);
-		opBW_B->redraw();
+		if (progStatus.UIsize == small_ui) {
+			opBW_A->resize(opBW->x(), opBW->y() + opBW->h(), opBW->w(), opBW->h());
+			opBW_A->redraw();
+			opBW_B->resize(opMODE->x(), opBW_A->y(), opBW_A->w(), opBW_A->h());
+			opBW_B->redraw();
+		}
+		try {
+			selrig->bandwidths_ = selrig->bwtable(vfo->imode);
+			for (size_t i = 0; i < selrig->bandwidths_.size(); i++) {
+				opBW_A->add(selrig->bandwidths_.at(i).c_str());
+				opBW_B->add(selrig->bandwidths_.at(i).c_str());
+			}
+			opBW_A->index(vfoA.iBW);
+			opBW_B->index(vfoB.iBW);
+		} catch (const std::exception& e) {
+			LOG_ERROR("%s", e.what());
+			opBW_A->index(0);
+			opBW_B->index(0);
+		}
+		opBW_A->callback((Fl_Callback*)cb_bw_A);
+		opBW_B->callback((Fl_Callback*)cb_bw_B);
+
+		opBW_A->redraw(); opBW_A->show();
+		opBW_B->redraw(); opBW_B->show();
+		return;
 	}
-	opBW_A->callback((Fl_Callback*)cb_bw_A);
-	opBW_A->show();
-	opBW_B->callback((Fl_Callback*)cb_bw_B);
-	opBW_B->show();
+}
+
+void cb_sdr2_A(Fl_Light_Button * b, void *)
+{
+	guard_lock A(&mutex_serial);
+	if (b->value()) {
+		selrig->selectB();
+		btnA->label("ch B");
+		btnA->redraw();
+	}
+	else {
+		selrig->selectA();
+		btnA->label("ch A");
+		btnA->redraw();
+	}
+	updateUI((void *)0);
+}
+
+void cb_sdr2_B(Fl_Light_Button * b, void *)
+{
+	guard_lock B(&mutex_serial);
+	if (b->value()) {
+		btnB->label("Rx 2");
+		if (selrig->name_ == rig_tci_sundx.name_)
+			rig_tci_sundx.set_slice(1);
+		else
+			rig_tci_sunpro.set_slice(1);
+	}
+	else {
+		btnB->label("Rx 1");
+		if (selrig->name_ == rig_tci_sundx.name_)
+			rig_tci_sundx.set_slice(0);
+		else
+			rig_tci_sunpro.set_slice(0);
+	}
+	btnB->redraw_label();
+	updateUI((void *)0);
+}
+
+void TRACED(init_sdr2)
+	btnA->label("ch A");
+	btnA->redraw_label();
+	btnA->callback((Fl_Callback *)cb_sdr2_A);
+	btnB->label("Rx 0");
+	btnB->redraw_label();
+	btnB->callback((Fl_Callback *)cb_sdr2_B);
 }
 
 extern void read_menus();
@@ -2401,6 +2522,17 @@ trace(1, "selrig->initialize()");
 		guard_lock gl_serial(&mutex_serial);
 		trace(1, "init_rig()");
 
+		// Xcvr Auto Power on as soon as possible
+		if (selrig->has_xcvr_auto_on_off && progStatus.xcvr_auto_on) {
+			progress->label("Auto Start");
+			progress->redraw_label();
+			update_progress(0);
+			selrig->set_xcvr_auto_on();
+			progress->label("Initializing");
+			progress->redraw_label();
+			update_progress(0);
+		}
+
 		init_special_controls();
 		init_external_tuner();
 		init_rit();
@@ -2425,17 +2557,6 @@ trace(1, "selrig->initialize()");
 		init_swr_control();
 		init_split_control();
 
-		// Xcvr Auto Power on as soon as possible
-		if (selrig->has_xcvr_auto_on_off && progStatus.xcvr_auto_on) {
-			progress->label("Auto Start");
-			progress->redraw_label();
-			update_progress(0);
-			selrig->set_xcvr_auto_on();
-			progress->label("Initializing");
-			progress->redraw_label();
-			update_progress(0);
-		}
-
 		if (selrig->name_ == rig_QCXP.name_) read_menus();
 
 if (!testmode && xcvr_name != rig_null.name_) {
@@ -2495,12 +2616,12 @@ Press 'Init' button."));
 
 		init_CIV();
 
-//		init_xcvr();
-
 		selrig->post_initialize();
 
 		init_TS990_special();
-		init_K3_KX3_special();
+		init_elecraft_xcvrs();
+		if (selrig->name_ == rig_tci_sundx.name_ || selrig->name_ == rig_tci_sunpro.name_ )
+			init_sdr2();
 
 		if (selrig->has_power_control) {
 			if (progStatus.use_rig_data)
@@ -2566,6 +2687,7 @@ void TRACED(init_title)
 	title = PACKAGE;
 	title += " ";
 	title.append(selrig->name_);
+	if (progStatus.xmlrpc_rig) title.append(" CLIENT");
 	mainwindow->label(title.c_str());
 }
 
@@ -2585,9 +2707,6 @@ void TRACED(initConfigDialog)
 		cntWriteDelay->value( srig->serial_write_delay );
 		query_interval->value( srig->serloop_timing );
 
-		btnRigCatEcho->value( srig->serial_echo );
-
-
 		lbox_catptt->index( srig->serial_catptt );
 		lbox_rtsptt->index( srig->serial_rtsptt );
 		lbox_dtrptt->index( srig->serial_dtrptt );
@@ -2643,7 +2762,6 @@ void TRACED(initStatusConfigDialog)
 	cntRigCatRetries->value( progStatus.serial_retries );
 	cntRigCatTimeout->value( progStatus.serial_timeout );
 	cntPostWriteDelay->value( progStatus.serial_post_write_delay );
-	btnRigCatEcho->value( progStatus.serial_echo );
 	query_interval->value( progStatus.serloop_timing );
 	cntWriteDelay->value( progStatus.serial_write_delay );
 
@@ -2666,15 +2784,26 @@ void TRACED(initStatusConfigDialog)
 	if (progStatus.use_tcpip) {
 		box_xcvr_connect->color(FL_BACKGROUND2_COLOR);
 		box_xcvr_connect->redraw();
+	} else if (progStatus.xcvr_serial_port == "xml_client") {
+			if (connect_to_client()) {
+				progStatus.xmlrpc_rig = true;
+				box_xcvr_connect->color(FL_GREEN);
+				box_xcvr_connect->redraw();
+			} else {
+				fl_alert2("Cannot connect to remote flrig");
+				LOG_WARN("Cannot connect to remote flrig");
+				progStatus.xmlrpc_rig = false;
+				exit(0);
+			}
 	} else {
 		if (startXcvrSerial()) {
 			selectCommPort->value(progStatus.xcvr_serial_port.c_str());
 			box_xcvr_connect->color(FL_GREEN);
 			box_xcvr_connect->redraw();
 		} else {
-			if (progStatus.xcvr_serial_port.compare("NONE") == 0) {
+			if (progStatus.xcvr_serial_port == "NONE") {
 				LOG_WARN("No comm port ... test mode");
-			} else {
+			} else if (!progStatus.xmlrpc_rig) {
 				fl_alert2("\
 Cannot open %s!\n\n\
 Check serial (COM) port connection\n\
@@ -2721,7 +2850,6 @@ void TRACED(initRigCombo)
 	int i = 0;
 	while (rigs[i] != NULL) {
 		selectRig->add(rigs[i]->name_.c_str(), (void*)rigs[i]);
-//std::cout << i+1 << " : " << rigs[i]->name_ << std::endl;
 		i++;
 	}
 
