@@ -32,7 +32,7 @@
 
 LOG_FILE_SOURCE(debug::LOG_RIGCONTROL);
 
-char traceinfo[500];
+char traceinfo[1000];
 
 bool SERIALDEBUG = false;
 
@@ -393,6 +393,7 @@ bool  Cserial::IOselect ()
 // Return type	  : # characters received
 // Argument		 : pointer to buffer; # chars to read; std::string terminator
 ///////////////////////////////////////////////////////
+
 int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::string find2)
 {
 	if (fd < 0) {
@@ -401,182 +402,81 @@ int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::
 	}
 
 	bool hex = false;
-	std::string s1, s2;
-
-	if (find1.length())
-		hex = hex || check_hex(find1.c_str(), find1.length());
-	if (find2.length())
-		hex = hex || check_hex(find2.c_str(), find2.length());
-	if (hex) {
-		s1 = str2hex(find1.c_str(), find1.length());
-		s2 = str2hex(find2.c_str(), find2.length());
-	} else {
-		s1 = find1;
-		size_t p = s1.find("\r\n");
-		if (p != std::string::npos) s1.replace(p,2,"<cr><lf>");
-		p = s1.find('\r');
-		if (p != std::string::npos) s1.replace(p,1,"<cr>");
-		p = s1.find('\n');
-		if (p != std::string::npos) s1.replace(p,1,"<lf>");
-
-		s2 = find2;
-		p = s2.find("\r\n");
-		if (p != std::string::npos) s2.replace(p,2,"<cr><lf>");
-		p = s2.find('\r');
-		if (p != std::string::npos) s2.replace(p,1,"<cr>");
-		p = s2.find('\n');
-		if (p != std::string::npos) s2.replace(p,1,"<lf>");
-	}
-
-	bool  find_two = (!find1.empty() && !find2.empty());
-	bool  find_one = (!find1.empty() && find2.empty());
-
-	if (find_two)
-		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer(... %d, %s, %s)", nchars, s1.c_str(), s2.c_str());
-	else if (find_one)
-		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer(... %d, %s)", nchars, s1.c_str());
-	else
-		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer(... %d)", nchars);
-
-	if (SERIALDEBUG)
-		ser_trace(1, traceinfo);
-
-	int retnum = 0;
-	int nread = 0;
-	int bytes = 0;
-
-	size_t p1, p2;
 
 	fd_set rfds;
 
 	FD_ZERO (&rfds);
 	FD_SET (fd, &rfds);
 
-	size_t tnow = zusec();
-	size_t start = tnow;
+	bool     timedout = false,
+			 echo = false;
+	int      bytes = 0;
+	size_t   retval = 0,
+			 maxchars = nchars + bytes_written,
+			 tnow = 0,
+			 start = 0;
 
-	do {
+	buf.clear();
 
+	start = tnow = zusec();
+
+	while (1) {
+		memset(uctemp, 0, sizeof(uctemp));
 		ioctl( fd, FIONREAD, &bytes);
 		if (bytes) {
-			unsigned char tempbuf[bytes + 1];
-			memset(tempbuf, 0, bytes + 1);
-
-			snprintf(traceinfo, sizeof(traceinfo), "bytes: %d", bytes);
-			if (SERIALDEBUG)
-				ser_trace(1, traceinfo);
-
-			retnum = read (fd, tempbuf, bytes);
-			if (retnum > 0 && retnum <= bytes) {
-				for (int nc = 0; nc < retnum; nc++)
-					buf += tempbuf[nc];
-				nread += retnum;
-			} else if (progStatus.serialtrace || SERIALDEBUG) {
-				char traceinfo[100];
-				snprintf(traceinfo, sizeof(traceinfo), "read(fd %d, tempbuf, 200) error: %s", fd,
-					(errno == EAGAIN ? "EAGAIN" :
-					errno == EWOULDBLOCK ? "EWOULDBLOCK" :
-					errno == EBADF ? "EBADF" :
-					errno == EFAULT? "EFAULT" :
-					errno == EINTR ? "EINTR" :
-					errno == EINVAL ? "EINVAL" :
-					errno == EIO ? "EIO" :
-					errno == EISDIR ? "EISDRI" : "OTHER"));
-					ser_trace(1, traceinfo);
-			}
-
-			if (find_two) {
-				p1 = buf.rfind(find1);
-				p2 = buf.rfind(find2);
-				if (p1 != std::string::npos &&
-					p2 != std::string::npos &&
-					p2 > p1) {
-					
-					if (progStatus.serialtrace || SERIALDEBUG) {
-					char traceinfo[100];
-						std::string srx = buf;
-						size_t p = srx.find("\r\n");
-						if (p != std::string::npos) srx.replace(p,2,"<cr><lf>");
-						p = srx.find('\r');
-						if (p != std::string::npos) srx.replace(p,1,"<cr>");
-						p = srx.find('\n');
-						if (p != std::string::npos) srx.replace(p,1,"<lf>");
-						bool hex = check_hex(buf.c_str(), buf.length());
-						snprintf(traceinfo, sizeof(traceinfo), "READBUFFER TWO [%0.3f msec]: %s",
-							(zusec() - start) * 1e-3,
-							(hex ? str2hex(buf.c_str(), buf.length()) : srx.c_str()) );
-						ser_trace(1, traceinfo);
-					}
-				}
-				return nread;
-			}
-
-			else if (find_one) {
-				p1 = buf.rfind(find1);
-				if (p1 != std::string::npos) {
-
-					if (progStatus.serialtrace || SERIALDEBUG) {
-						char traceinfo[100];
-						std::string srx = buf;
-						size_t p = srx.find("\r\n");
-						if (p != std::string::npos) srx.replace(p,2,"<cr><lf>");
-						p = srx.find('\r');
-						if (p != std::string::npos) srx.replace(p,1,"<cr>");
-						p = srx.find('\n');
-						if (p != std::string::npos) srx.replace(p,1,"<lf>");
-						bool hex = check_hex(buf.c_str(), buf.length());
-						snprintf(traceinfo, sizeof(traceinfo), "READBUFFER ONE [%0.3f msec]: %s",
-							(zusec() - start) * 1e-3,
-							(hex ? str2hex(buf.c_str(), buf.length()) : srx.c_str()) );
-						ser_trace(1, traceinfo);
-					}
-					return nread;
+			if ( (retval = read (fd, uctemp, bytes)) > 0) {
+				for (size_t nc = 0; nc < retval && nc < sizeof(uctemp); nc++) {
+					buf += uctemp[nc];
 				}
 			}
-
-			else if ( nread >= nchars ) {
-				if (progStatus.serialtrace || SERIALDEBUG) {
-					char traceinfo[100];
-					std::string srx = buf;
-					size_t p = srx.find("\r\n");
-					if (p != std::string::npos) srx.replace(p,2,"<cr><lf>");
-					p = srx.find('\r');
-					if (p != std::string::npos) srx.replace(p,1,"<cr>");
-					p = srx.find('\n');
-					if (p != std::string::npos) srx.replace(p,1,"<lf>");
-					bool hex = check_hex(buf.c_str(), buf.length());
-					snprintf(traceinfo, sizeof(traceinfo), "READBUFFER NCHARS [%0.3f msec]: %s",
-						(zusec() - start) * 1e-3,
-						(hex ? str2hex(buf.c_str(), buf.length()) : srx.c_str()) );
-					ser_trace(1, traceinfo);
-				}
-				return nread;
-			}
-
-			tnow = zusec();
 		}
+		if (!find1.empty() && buf.find(find1) == (buf.length() - find1.length())) break;
+		if (!find2.empty() && buf.find(find2) == (buf.length() - find2.length())) break;
+
+		timedout = ( (zusec() - tnow) > (size_t)(progStatus.serial_timeout * 1000));
+
+		// test for icom echo
+		if ((buf.length() >= (size_t)nchars) && ((buf[3] & 0xFF) == 0xE0))
+			echo = true;
+		if (buf.length() >= (echo ? maxchars : (size_t)nchars)) break;
+
+		if (timedout) break;
 
 		MilliSleep(1);
-
-	} while ( (zusec() - tnow) < (size_t)(progStatus.serial_timeout * 1000L));
-
-	if (progStatus.serialtrace || SERIALDEBUG) {
-		char traceinfo[100];
-		std::string srx = buf;
-		size_t p = srx.find("\r\n");
-		if (p != std::string::npos) srx.replace(p,2,"<cr><lf>");
-		p = srx.find('\r');
-		if (p != std::string::npos) srx.replace(p,1,"<cr>");
-		p = srx.find('\n');
-		if (p != std::string::npos) srx.replace(p,1,"<lf>");
-		bool hex = check_hex(buf.c_str(), buf.length());
-		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer TIMED OUT [%0.3f msec]: %s",
-			(zusec() - start) * 1e-3,
-			(hex ? str2hex(buf.c_str(), buf.length()) : srx.c_str()) );
-		ser_trace(1, traceinfo);
 	}
 
-	return nread;
+	if (echo)
+		buf = buf.substr(bytes_written);
+	if (buf.length() > (size_t)nchars) buf.erase(nchars);
+
+	size_t readtime = zusec() - start;
+
+	memset(traceinfo, 0, sizeof(traceinfo));
+	hex = check_hex(buf.c_str(), buf.length());
+
+	snprintf(traceinfo, sizeof(traceinfo), 
+		"ReadBuffer [%f msec]: %s",
+		readtime / 1000.0,
+		(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()));
+
+	LOG_DEBUG("%s", traceinfo);
+	if (progStatus.serialtrace)
+		ser_trace(1, traceinfo);
+
+	if (timedout) {
+		memset(traceinfo, 0, sizeof(traceinfo));
+		snprintf(traceinfo, sizeof(traceinfo), 
+			"ReadBuffer FAILED [%f msec] wanted %d chars, read %lu chars",
+			(zusec() - start) / 1000.0,
+			nchars,
+			buf.length());
+		LOG_ERROR("%s", traceinfo);
+
+		if (progStatus.serialtrace)
+			ser_trace(1, traceinfo);
+	}
+
+	return buf.length();
 }
 
 ///////////////////////////////////////////////////////
@@ -592,35 +492,25 @@ int Cserial::WriteBuffer(const char *buff, int n)
 		return 0;
 	}
 
+	std::string sw = std::string(buff, (std::size_t) n);
 	if (progStatus.serialtrace || SERIALDEBUG) {
-		std::string sw = std::string(buff, (std::size_t) n);
 		size_t p = sw.rfind("\r\n");
 		if (p == (sw.length() - 2) ) {
 			sw.replace(p, 2, "<cr><lf>");
-			ser_trace(2, "WRITE BUFFER: ", sw.c_str());
+			ser_trace(2, "WriteBuffer: ", sw.c_str());
 		} else  {
 			bool hex = check_hex(sw.c_str(), sw.length());
-			ser_trace(2, "WRITE BUFFER: ", (hex ? str2hex(sw.c_str(), sw.length()) : sw.c_str()));
+			ser_trace(2, "WriteBuffer: ", (hex ? str2hex(sw.c_str(), sw.length()) : sw.c_str()));
 		}
 	}
 
-	int ret = 0;
-	if (progStatus.serial_write_delay) {
-		for (int j = 0; j < n; j++) {
-			ret = write (fd, &buff[j], 1);
-			MilliSleep(progStatus.serial_write_delay);
-			if (!ret) break;
-		}
-	} else
-		ret = write (fd, buff, n);
+	FlushBuffer();
+	int ret = write (fd, buff, n);
 
-	int timeout = progStatus.serial_post_write_delay;
-	while (timeout > 0) {
-		if (timeout > 10) MilliSleep(10);
-		else MilliSleep(timeout);
-		timeout -= 10;
-		Fl::awake();
-	}
+	bytes_written = n;
+
+	if (progStatus.serial_post_write_delay)
+		MilliSleep(progStatus.serial_post_write_delay);
 
 	return ret;
 }
@@ -649,6 +539,7 @@ void Cserial::FlushBuffer()
 	if (fd < 0)
 		return;
 	tcflush (fd, TCIFLUSH);
+	
 }
 
 //=============================================================================
@@ -707,26 +598,23 @@ bool Cserial::OpenPort()
 			  0);
 
 	if (hComm == INVALID_HANDLE_VALUE) {
-		LOG_ERROR("Open Comm port %s ; hComm = %u", 
+		snprintf(traceinfo, sizeof(traceinfo),
+			"INVALID_HANDLE_VALUE: Open Comm port %s ; hComm = %llu\n",
 			COMportname.c_str(),
 			(unsigned long long)hComm);
+		LOG_ERROR("%s", traceinfo); 
 
-		if (progStatus.serialtrace || SERIALDEBUG) {
-			snprintf(traceinfo, sizeof(traceinfo),
-				"INVALID_HANDLE_VALUE: Open Comm port %s ; hComm = %u\n",
-				COMportname.c_str(),
-				(unsigned long long)hComm);
-			ser_trace(1, traceinfo);
-		}
+		if (progStatus.serialtrace) ser_trace(1, traceinfo);
 
 		return false;
 	}
 
 	if (progStatus.serialtrace || SERIALDEBUG) {
 		snprintf(traceinfo, sizeof(traceinfo),
-			"Open Comm port %s ; hComm = %u\n",
+			"Open Comm port %s ; hComm = %llu\n",
 			COMportname.c_str(),
 			(unsigned long long)hComm);
+		LOG_INFO("%s", traceinfo);
 		ser_trace(1, traceinfo);
 		}
 
@@ -810,10 +698,10 @@ static  DWORD dwBytesTxD=0;
 int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::string find2)
 {
 	if (hComm == INVALID_HANDLE_VALUE) {
-		if (progStatus.serialtrace || SERIALDEBUG) {
-			snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer, invalid handle\n");
+		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer, invalid handle\n");
+		LOG_ERROR("%s", traceinfo);
+		if (progStatus.serialtrace || SERIALDEBUG)
 			ser_trace(1, traceinfo);
-		}
 		return 0;
 	}
 
@@ -845,103 +733,83 @@ int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::
 		if (p != std::string::npos) s2.replace(p,1,"<lf>");
 	}
 
-	bool  find_two = (!find1.empty() && !find2.empty());
-	bool  find_one = (!find1.empty() && find2.empty());
+//	bool  find_two = (!find1.empty() && !find2.empty());
+//	bool  find_one = (!find1.empty() && find2.empty());
 
-	if (find_two)
-		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer(... %d, %s, %s)", nchars, s1.c_str(), s2.c_str());
-	else if (find_one)
-		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer(... %d, %s)", nchars, s1.c_str());
-	else
-		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer(... %d)", nchars);
+//	if (find_two)
+//		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer: %s  |  %s", s1.c_str(), s2.c_str());
+//	else if (find_one)
+//		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer XXX: %s", s1.c_str());
+//	else
+//		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer: %d chars", nchars);
 
-	if (progStatus.serialtrace || SERIALDEBUG)
-		ser_trace(1, traceinfo);
+//	LOG_DEBUG("%s", traceinfo);
+//	if (progStatus.serialtrace)
+//		ser_trace(1, traceinfo);
 
-	DWORD dwRead = 0;
-	int   nread = 0;
-	BOOL  retval = 0;
-	unsigned char uctemp[nchars + 1];
+	memset(traceinfo, 0, sizeof(traceinfo));
 
-	size_t tnow = zusec();
-	size_t start = tnow;
+	long unsigned int thisread = 0;
+	size_t maxchars = nchars + nBytesWritten;
+	double start = zusec();
 
-	do {
+	bool echo = false;
+	bool retval = false;
 
-		memset(uctemp, 0, nchars + 1);
-		retval = ReadFile(hComm, uctemp, nchars - nread, &dwRead, NULL);
+	std::string sbuf;
+	sbuf.clear();
 
-		if (progStatus.serialtrace || SERIALDEBUG) {
-			int hex = check_hex(buf.c_str(), buf.length());
-			snprintf(traceinfo, sizeof(traceinfo), 
-				"ReadFile retval: %d, dwRead: %ld, %s",
-				retval,
-				dwRead,
-				(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()) );
-			ser_trace(1, traceinfo);
-		}
-
-		if (retval == 0) {
-			goto doloop;
-		}
-
-		if (dwRead == 0) {
-			goto doloop;
-		}
-
-		for (int nc = 0; nc < (int)dwRead; nc++)
-			buf += uctemp[nc];
-
-		nread += (int)dwRead;
-
-		if (find_two) {
-			size_t p1 = buf.rfind(find1);
-			size_t p2 = buf.rfind(find2);
-			if (p1 != std::string::npos &&
-				p2 != std::string::npos &&
-				p2 > p1) {
-				if (progStatus.serialtrace || SERIALDEBUG) {
-					hex = check_hex(buf.c_str(), buf.length());
-					snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer TWO [%0.3f msec]: %s", (zusec() - start) * 1e-3,
-						(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()));
-					ser_trace(1, traceinfo);
-				}
-				return nread;
+	while ( (zusec() - start) < (progStatus.serial_timeout * 1000.0) ) {
+		memset(uctemp, 0, sizeof(uctemp));
+		if ( (retval = ReadFile (hComm, uctemp, maxchars, &thisread, NULL)) ) {
+			for (size_t n = 0; n < thisread && n < sizeof(uctemp); n++) {
+				sbuf += uctemp[n];
 			}
 		}
-
-		else if (find_one) {
-			if (buf.rfind(find1) != std::string::npos) {
-				if (progStatus.serialtrace || SERIALDEBUG) {
-					hex = check_hex(buf.c_str(), buf.length());
-					snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer ONE [%0.3f msec]: %s", (zusec() - start) * 1e-3,
-						(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()) );
-					ser_trace(1, traceinfo);
-				}
-				return nread;
-			}
-		}
-
-		else if ( nread >= nchars ) {
-			if (progStatus.serialtrace || SERIALDEBUG) {
-				hex = check_hex(buf.c_str(), buf.length());
-				snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer NCHARS [%0.3f msec]: %s", (zusec() - start) * 1e-3,
-					(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()) );
-				ser_trace(1, traceinfo);
-			}
-			return nread;
-		}
-		tnow = zusec();
-doloop:
-		MilliSleep(1);
-	} while ( (zusec() - tnow) < (size_t)(progStatus.serial_timeout * 1000L));
-
-	if (progStatus.serialtrace || SERIALDEBUG) {
-		hex = check_hex(buf.c_str(), buf.length());
-		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer TIMED OUT [%0.3f msec]: %s", (zmsec() - start) * 1e-3,
-			(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()) );
-		ser_trace(1, traceinfo);
+		// test for icom echo
+		if ((sbuf.length() >= (size_t)nchars) && ((sbuf[3] & 0xFF) == 0xE0))
+			echo = true;
+		if (sbuf.length() >= (echo ? maxchars : (size_t)nchars)) break;
+		if (!find1.empty() && sbuf.find(find1) == (sbuf.length() - find1.length())) break;
+		if (!find2.empty() && sbuf.find(find2) == (sbuf.length() - find2.length())) break;
+		
+		if (!thisread || !retval) MilliSleep(1);
 	}
+
+	double readtime = (zusec() - start) / 1000.0;
+	snprintf(traceinfo, sizeof(traceinfo), 
+		"ReadBuffer [%0.2f msec] (%u): %s",
+		readtime, sbuf.length(), 
+		(hex ? str2hex(buf.c_str(), buf.length()) : sbuf.c_str()));
+	if (progStatus.serialtrace)
+		ser_trace(2, "1:", traceinfo);
+
+	if (echo)
+		sbuf = sbuf.substr(nBytesWritten);
+	if (sbuf.length() > (size_t)nchars) sbuf.erase(nchars);
+
+	buf = sbuf;
+	int nread = (int)buf.length();
+
+//	snprintf(traceinfo, sizeof(traceinfo), 
+//		"ReadBuffer [%0.2f msec] (%d): %s",
+//		readtime, nread, 
+//		(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()));
+
+//	LOG_DEBUG("%s", traceinfo);
+//	if (progStatus.serialtrace)
+//		ser_trace(1, traceinfo);
+
+	if (nread >= nchars) return nread;
+
+	snprintf(traceinfo, sizeof(traceinfo), 
+		"ReadBuffer FAILED [%0.2f msec], read %d bytes",
+		readtime, nread);
+	LOG_ERROR("%s", traceinfo);
+
+	if (progStatus.serialtrace)
+		ser_trace(2, "2:", traceinfo);
+
 	return nread;
 }
 
@@ -986,34 +854,19 @@ int Cserial::WriteBuffer(const char *buff, int n)
 		size_t p = sw.rfind("\r\n");
 		if (p == (sw.length() - 2) ) {
 			sw.replace(p, 2, "<cr><lf>");
-			ser_trace(2, "WRITE BUFFER: ", sw.c_str());
+			ser_trace(2, "WriteBuffer: ", sw.c_str());
 		} else  {
 			bool hex = check_hex(sw.c_str(), sw.length());
-			ser_trace(2, "WRITE BUFFER: ", (hex ? str2hex(sw.c_str(), sw.length()) : sw.c_str()));
+			ser_trace(2, "WriteBuffer: ", (hex ? str2hex(sw.c_str(), sw.length()) : sw.c_str()));
 		}
 	}
+	FlushBuffer();
+	WriteFile (hComm, buff, n,  &nBytesWritten, NULL);
+	
+	if (progStatus.serial_post_write_delay)
+		MilliSleep(progStatus.serial_post_write_delay);
 
-	int ret = 0;
-	if (progStatus.serial_write_delay) {
-		for (int j = 0; j < n; j++) {
-			WriteFile (hComm, &buff[j], 1, &nBytesWritten, NULL);
-			MilliSleep(progStatus.serial_write_delay);
-			ret += nBytesWritten;
-		}
-	} else {
-		WriteFile (hComm, buff, n, &nBytesWritten, NULL);
-		ret = nBytesWritten;
-	}
-
-	int timeout = progStatus.serial_post_write_delay;
-	while (timeout > 0) {
-		if (timeout > 10) MilliSleep(10);
-		else MilliSleep(timeout);
-		timeout -= 10;
-		Fl::awake();
-	}
-
-	return ret;
+	return nBytesWritten;
 }
 
 
@@ -1028,42 +881,16 @@ int Cserial::WriteBuffer(const char *buff, int n)
 // Argument		 : DWORD WriteTotalTimeoutConstant
 ///////////////////////////////////////////////////////
 bool Cserial::SetCommunicationTimeouts(
-	DWORD ReadIntervalTimeout, // msec
+	DWORD ReadIntervalTimeout,
 	DWORD ReadTotalTimeoutMultiplier,
 	DWORD ReadTotalTimeoutConstant,
 	DWORD WriteTotalTimeoutMultiplier,
 	DWORD WriteTotalTimeoutConstant
 )
 {
-	if((bPortReady = GetCommTimeouts (hComm, &CommTimeoutsSaved))==0)   {
+	if((bPortReady = GetCommTimeouts (hComm, &CommTimeoutsSaved)) == 0)   {
 		return false;
 	}
-	LOG_ERROR("\n\
-Read Interval Timeout............... %ld\n\
-Read Total Timeout Multiplier....... %ld\n\
-Read Total Timeout Constant Timeout. %ld\n\
-Write Total Timeout Constant........ %ld\n\
-Write Total Timeout Multiplier...... %ld",
-	CommTimeoutsSaved.ReadIntervalTimeout,
-	CommTimeoutsSaved.ReadTotalTimeoutMultiplier,
-	CommTimeoutsSaved.ReadTotalTimeoutConstant,
-	CommTimeoutsSaved.WriteTotalTimeoutConstant,
-	CommTimeoutsSaved.WriteTotalTimeoutMultiplier);
-
-	if (progStatus.serialtrace || SERIALDEBUG) {
-		snprintf(traceinfo, sizeof(traceinfo), "\
-Read Interval Timeout............... %ld\n\
-Read Total Timeout Multiplier....... %ld\n\
-Read Total Timeout Constant Timeout. %ld\n\
-Write Total Timeout Constant........ %ld\n\
-Write Total Timeout Multiplier...... %ld\n",
-		CommTimeoutsSaved.ReadIntervalTimeout,
-		CommTimeoutsSaved.ReadTotalTimeoutMultiplier,
-		CommTimeoutsSaved.ReadTotalTimeoutConstant,
-		CommTimeoutsSaved.WriteTotalTimeoutConstant,
-		CommTimeoutsSaved.WriteTotalTimeoutMultiplier);
-		ser_trace(1, traceinfo);
-	}
 
 	CommTimeouts.ReadIntervalTimeout = ReadIntervalTimeout;
 	CommTimeouts.ReadTotalTimeoutMultiplier = ReadTotalTimeoutMultiplier;
@@ -1073,7 +900,36 @@ Write Total Timeout Multiplier...... %ld\n",
 
 	bPortReady = SetCommTimeouts (hComm, &CommTimeouts);
 
-	if(bPortReady ==0) {
+	snprintf(traceinfo, sizeof(traceinfo), "\n\
+============     COMM TIMEOUTS     ================\n\
+Saved Read Interval Timeout............... %ld\n\
+Saved Read Total Timeout Multiplier....... %ld\n\
+Saved Read Total Timeout Constant Timeout. %ld\n\
+Saved Write Total Timeout Constant........ %ld\n\
+Saved Write Total Timeout Multiplier...... %ld\n\
+===================================================\n\
+Set Read Interval Timeout................. %ld\n\
+Set Read Total Timeout Multiplier......... %ld\n\
+Set Read Total Timeout Constant Timeout... %ld\n\
+Set Write Total Timeout Constant.......... %ld\n\
+Set Write Total Timeout Multiplier........ %ld\n\
+===================================================",
+	CommTimeoutsSaved.ReadIntervalTimeout,
+	CommTimeoutsSaved.ReadTotalTimeoutMultiplier,
+	CommTimeoutsSaved.ReadTotalTimeoutConstant,
+	CommTimeoutsSaved.WriteTotalTimeoutConstant,
+	CommTimeoutsSaved.WriteTotalTimeoutMultiplier,
+	CommTimeouts.ReadIntervalTimeout,
+	CommTimeouts.ReadTotalTimeoutMultiplier,
+	CommTimeouts.ReadTotalTimeoutConstant,
+	CommTimeouts.WriteTotalTimeoutConstant,
+	CommTimeouts.WriteTotalTimeoutMultiplier);
+
+	LOG_INFO("%s", traceinfo);
+
+	if (progStatus.serialtrace) ser_trace(1, traceinfo);
+	
+	if (bPortReady == 0) {
 		CloseHandle(hComm);
 		return false;
 	}
@@ -1152,18 +1008,17 @@ Write Total Timeout Multiplier...... %ld\n",
 
 bool Cserial::SetCommTimeout() {
 	return SetCommunicationTimeouts (
-		0,		// Read Interval Timeout
-		0,		// Read Total Timeout Multiplier
-		50,		// Read Total Timeout Constant
-		50,		// Write Total Timeout Constant
-		0		// Write Total Timeout Multiplier
-		);
-//	CommTimeouts.ReadIntervalTimeout = 50;
-//	CommTimeouts.ReadTotalTimeoutConstant = 50;
-//	CommTimeouts.ReadTotalTimeoutMultiplier=10;
-//	CommTimeouts.WriteTotalTimeoutMultiplier=10;
-//	CommTimeouts.WriteTotalTimeoutConstant = 50;
-
+	// Read Interval Timeout
+		MAXDWORD,
+	// Read Total Timeout Multiplier
+		MAXDWORD,
+	// Read Total Timeout Constant
+		1, // progStatus.serial_timeout ? progStatus.serial_timeout : 5,
+	// Write Total Timeout Constant
+		0,
+	// Write Total Timeout Multiplier
+		0
+	);
 }
 
 ///////////////////////////////////////////////////////
@@ -1235,6 +1090,11 @@ bool Cserial::ConfigurePort(
 	}
 
 	if (progStatus.serialtrace || SERIALDEBUG) {
+		ser_trace(1, traceinfo);
+	}
+
+	bPortReady = SetCommState(hComm, &dcb);
+
 	snprintf(traceinfo, sizeof(traceinfo), "\
 \n\
 Set Comm State:\n\
@@ -1256,41 +1116,40 @@ DCB.XoffChar        %d\n\
 DCB.fAbortOnError   %d\n\
 DCB.fOutxCtsFlow    %d\n\
 DCB.fOutxDsrFlow    %d\n",
-	(int)dcb.DCBlength,
-	(int)dcb.BaudRate,
-	(int)dcb.ByteSize,
-	(int)dcb.Parity,
-	(int)dcb.StopBits,
-	(int)dcb.fBinary,
-	(int)dcb.fDtrControl,
-	(int)dcb.fRtsControl,
-	(int)dcb.fDsrSensitivity,
-	(int)dcb.fParity,
-	(int)dcb.fOutX,
-	(int)dcb.fInX,
-	(int)dcb.fNull,
-	(int)dcb.XonChar,
-	(int)dcb.XoffChar,
-	(int)dcb.fAbortOnError,
-	(int)dcb.fOutxCtsFlow,
-	(int)dcb.fOutxDsrFlow);
-		ser_trace(1, traceinfo);
-	}
+		(int)dcb.DCBlength,
+		(int)dcb.BaudRate,
+		(int)dcb.ByteSize,
+		(int)dcb.Parity,
+		(int)dcb.StopBits,
+		(int)dcb.fBinary,
+		(int)dcb.fDtrControl,
+		(int)dcb.fRtsControl,
+		(int)dcb.fDsrSensitivity,
+		(int)dcb.fParity,
+		(int)dcb.fOutX,
+		(int)dcb.fInX,
+		(int)dcb.fNull,
+		(int)dcb.XonChar,
+		(int)dcb.XoffChar,
+		(int)dcb.fAbortOnError,
+		(int)dcb.fOutxCtsFlow,
+		(int)dcb.fOutxDsrFlow);
 
-	bPortReady = SetCommState(hComm, &dcb);
+	LOG_INFO("%s", traceinfo);
 
-	if (progStatus.serialtrace || SERIALDEBUG) {
-		long err = GetLastError();
-		snprintf(traceinfo, sizeof(traceinfo),
-			"SetCommState handle %u, returned %d, error = %d\n",
-			(unsigned long long)hComm, bPortReady, (int)err);
-		ser_trace(1, traceinfo);
-	}
+	if (progStatus.serialtrace) ser_trace(1, traceinfo);
 
 	if (bPortReady == 0) {
+		long err = GetLastError();
+		snprintf(traceinfo, sizeof(traceinfo),
+			"SetCommState handle %llu, returned %d, error = %d\n",
+			(unsigned long long)hComm, bPortReady, (int)err);
+		LOG_ERROR("%s", traceinfo);
+		ser_trace(1, traceinfo);
 		CloseHandle(hComm);
 		return false;
 	}
+
 	return SetCommTimeout();
 }
 
