@@ -15,7 +15,10 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
-#include <config.h>
+
+#include "config.h"
+#include "compat.h" // Must precede all FL includes
+
 
 #include "XmlRpcServerConnection.h"
 
